@@ -270,9 +270,15 @@ class Bugzilla(object):
         """
         from .oldclasses import RHBugzilla  # pylint: disable=cyclic-import
 
-        if self._detect_is_redhat_bugzilla():
+        if not self._detect_is_redhat_bugzilla():
+            return
+
+        self._is_redhat_bugzilla = True
+        if self.__class__ == Bugzilla:
+            # Overriding the class doesn't have any functional effect,
+            # but we continue to do it for API back compat incase anyone
+            # is doing any class comparison. We should drop this in the future
             self.__class__ = RHBugzilla
-            self._is_redhat_bugzilla = True
 
     def _get_field_aliases(self):
         # List of field aliases. Maps old style RHBZ parameter
@@ -612,7 +618,7 @@ class Bugzilla(object):
         except Exception as e:
             log.debug("Login exception: %s", str(e), exc_info=True)
             raise BugzillaError("Login failed: %s" %
-                    BugzillaError.get_bugzilla_error_string(e))
+                    BugzillaError.get_bugzilla_error_string(e)) from None
 
     def interactive_save_api_key(self):
         """
@@ -1316,7 +1322,7 @@ class Bugzilla(object):
                 raise
             raise BugzillaError("%s\nYour bugzilla instance does not "
                 "appear to support API queries derived from bugzilla "
-                "web URL queries." % e)
+                "web URL queries." % e) from None
 
         log.debug("Query returned %s bugs", len(r['bugs']))
         return [Bug(self, dict=b,
@@ -1438,7 +1444,8 @@ class Bugzilla(object):
                      internal_whiteboard=None,
                      sub_component=None,
                      flags=None,
-                     comment_tags=None):
+                     comment_tags=None,
+                     minor_update=None):
         """
         Returns a python dict() with properly formatted parameters to
         pass to update_bugs(). See bugzilla documentation for the format
@@ -1525,6 +1532,7 @@ class Bugzilla(object):
         s("work_time", work_time, float)
         s("flags", flags)
         s("comment_tags", comment_tags, listify)
+        s("minor_update", minor_update, bool)
 
         add_dict("blocks", blocks_add, blocks_remove, blocks_set,
                  convert=int)
